@@ -1,6 +1,9 @@
+import datetime
+from copy import deepcopy
+
 from .resource_constants import Initiator, TestStatus, DriverMode
 from .api_request import APIRequest
-from .resources import user_cred
+from .resources import user_cred, test_v1, test_result_v1
 from .resources import test_suite
 from .resources import test_case
 from .resources import job
@@ -37,6 +40,8 @@ class ZafiraClient:
     # actual API endpoints
     TEST_RUNS_PATH_V1 = '/api/reporting/v1/test-runs?projectKey={}'
     REFRESH_TOKEN_PATH = "/api/iam/v1/auth/refresh"
+    TESTS_PATH_V1 = '/api/reporting/v1/test-runs/{}/tests'
+    TESTS_FINISH_PATH_V1 = '/api/reporting/v1/test-runs/{}/tests/{}'
 
     INSTANCE = None
 
@@ -107,12 +112,14 @@ class ZafiraClient:
     #     return self.api.send_post(ZafiraClient.TEST_RUNS_PATH, test_run, headers=self.init_auth_headers(),
     #                               default_err_msg="Unable to start test run")
 
-    def start_test_run(self, uuid, name, started_at, framework, project):
-        test_run_v1["uuid"] = uuid
-        test_run_v1["name"] = name
-        test_run_v1["startedAt"] = started_at
-        test_run_v1["framework"] = framework
-        return self.api.send_post(ZafiraClient.TEST_RUNS_PATH_V1.format(project), test_run_v1, headers=self.init_auth_headers(),
+    def start_test_run(self, name, started_at, framework, project):
+        body = deepcopy(test_run_v1)
+        body["name"] = name
+        started_at = started_at.replace(tzinfo=datetime.timezone.utc)
+        body["startedAt"] = started_at.isoformat()
+        body["framework"] = framework
+        return self.api.send_post(ZafiraClient.TEST_RUNS_PATH_V1.format(project), body,
+                                  headers=self.init_auth_headers(),
                                   default_err_msg="Unable to start test run")
 
 
@@ -128,23 +135,40 @@ class ZafiraClient:
         return self.api.send_post(ZafiraClient.TEST_RUNS_ABORT_PATH.format(test_run_id),
                                   headers=self.init_auth_headers(), default_err_msg="Unable to find test run by id")
 
-    def start_test(self, test_run_id, test_case_id, test_name, start_time, ci_test_id,
-                   status=TestStatus.IN_PROGRESS.value, test_class=None,  # noqa F405
-                   test_group=None, work_items=None):
-        test["testRunId"] = test_run_id
-        test["testCaseId"] = test_case_id
-        test["name"] = test_name
-        test["ciTestId"] = ci_test_id
-        test["startTime"] = start_time
-        test["testClass"] = test_class
-        test["status"] = status
-        test["workItems"] = work_items
-        test["testGroup"] = test_group
-        return self.api.send_post(ZafiraClient.TESTS_PATH, test, headers=self.init_auth_headers(),
+    # def start_test(self, test_run_id, test_case_id, test_name, start_time, ci_test_id,
+    #                status=TestStatus.IN_PROGRESS.value, test_class=None,  # noqa F405
+    #                test_group=None, work_items=None):
+    #     test["testRunId"] = test_run_id
+    #     test["testCaseId"] = test_case_id
+    #     test["name"] = test_name
+    #     test["ciTestId"] = ci_test_id
+    #     test["startTime"] = start_time
+    #     test["testClass"] = test_class
+    #     test["status"] = status
+    #     test["workItems"] = work_items
+    #     test["testGroup"] = test_group
+    #     return self.api.send_post(ZafiraClient.TESTS_PATH, test, headers=self.init_auth_headers(),
+    #                               default_err_msg="Unable to start test")
+
+    def start_test(self, uid, test_run_id, test_name, started_at, class_name):
+        body = deepcopy(test_v1)
+        body["uuid"] = uid
+        body["name"] = test_name
+        started_at = started_at.replace(tzinfo=datetime.timezone.utc)
+        body["startedAt"] = started_at.isoformat()
+        body["className"] = class_name
+        return self.api.send_post(ZafiraClient.TESTS_PATH_V1.format(test_run_id), body, headers=self.init_auth_headers(),
                                   default_err_msg="Unable to start test")
 
-    def finish_test(self, test):
-        return self.api.send_post(ZafiraClient.TEST_FINISH_PATH.format(test["id"]), test,
+    def finish_test(self, test_run_id, test_id, test):
+        body = deepcopy(test_result_v1)
+        body["id"] = test_id
+        body["uuid"] = test["uuid"]
+        body["name"] = test["name"]
+        body["startedAt"] = test["startedAt"]
+        body["className"] = test["className"]
+        body["endedAt"] = datetime.datetime.utcnow().replace(tzinfo=datetime.timezone.utc).isoformat()
+        return self.api.send_put(ZafiraClient.TESTS_FINISH_PATH_V1.format(test_run_id, test_id), body,
                                   headers=self.init_auth_headers(), default_err_msg="Unable to finish test")
 
     def delete_test_by_id(self, test_id):
